@@ -8,7 +8,7 @@ use Dancer2::Plugin;
 use Class::Load qw(try_load_class);
 use Session::Token;
 
-our $VERSION = '0.501';
+our $VERSION = '0.502';
 
 my $settings;
 
@@ -212,7 +212,7 @@ and should do at least the following:
     };
     
     any '/logout' => sub {
-        session->destroy;
+        app->destroy_session;
     };
     
 
@@ -1575,6 +1575,8 @@ Gabor Szabo (GH #11, #16, #18).
 
 Evan Brown (GH #20, #32).
 
+Jason Lewis (Unix provider problem).
+
 =head1 LICENSE AND COPYRIGHT
 
 
